==> zio-aws-codepipeline_2.12-5.17.129.3-sources.jar: zio/aws/codepipeline/model/UpdatePipelineResponse.scala <==
package zio.aws.codepipeline.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class UpdatePipelineResponse(
    pipeline: Option[zio.aws.codepipeline.model.PipelineDeclaration] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.codepipeline.model.UpdatePipelineResponse = {
    import UpdatePipelineResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.codepipeline.model.UpdatePipelineResponse
      .builder()
      .optionallyWith(pipeline.map(value => value.buildAwsValue()))(_.pipeline)
      .build()
  }
  def asReadOnly: zio.aws.codepipeline.model.UpdatePipelineResponse.ReadOnly =
    zio.aws.codepipeline.model.UpdatePipelineResponse.wrap(buildAwsValue())
}
object UpdatePipelineResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.codepipeline.model.UpdatePipelineResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.codepipeline.model.UpdatePipelineResponse =
      zio.aws.codepipeline.model
        .UpdatePipelineResponse(pipeline.map(value => value.asEditable))
    def pipeline
        : Option[zio.aws.codepipeline.model.PipelineDeclaration.ReadOnly]
    def getPipeline: ZIO[
      Any,
      AwsError,
      zio.aws.codepipeline.model.PipelineDeclaration.ReadOnly
    ] = AwsError.unwrapOptionField("pipeline", pipeline)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.codepipeline.model.UpdatePipelineResponse
  ) extends zio.aws.codepipeline.model.UpdatePipelineResponse.ReadOnly {
    override val pipeline
        : Option[zio.aws.codepipeline.model.PipelineDeclaration.ReadOnly] =
      scala
        .Option(impl.pipeline())
        .map(value =>
          zio.aws.codepipeline.model.PipelineDeclaration.wrap(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.codepipeline.model.UpdatePipelineResponse
  ): zio.aws.codepipeline.model.UpdatePipelineResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-codepipeline_2.13-5.17.267.6-sources.jar: zio/aws/codepipeline/model/UpdatePipelineResponse.scala <==
package zio.aws.codepipeline.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class UpdatePipelineResponse(
    pipeline: Optional[zio.aws.codepipeline.model.PipelineDeclaration] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.codepipeline.model.UpdatePipelineResponse = {
    import UpdatePipelineResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.codepipeline.model.UpdatePipelineResponse
      .builder()
      .optionallyWith(pipeline.map(value => value.buildAwsValue()))(_.pipeline)
      .build()
  }
  def asReadOnly: zio.aws.codepipeline.model.UpdatePipelineResponse.ReadOnly =
    zio.aws.codepipeline.model.UpdatePipelineResponse.wrap(buildAwsValue())
}
object UpdatePipelineResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.codepipeline.model.UpdatePipelineResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.codepipeline.model.UpdatePipelineResponse =
      zio.aws.codepipeline.model
        .UpdatePipelineResponse(pipeline.map(value => value.asEditable))
    def pipeline
        : Optional[zio.aws.codepipeline.model.PipelineDeclaration.ReadOnly]
    def getPipeline: ZIO[
      Any,
      AwsError,
      zio.aws.codepipeline.model.PipelineDeclaration.ReadOnly
    ] = AwsError.unwrapOptionField("pipeline", pipeline)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.codepipeline.model.UpdatePipelineResponse
  ) extends zio.aws.codepipeline.model.UpdatePipelineResponse.ReadOnly {
    override val pipeline
        : Optional[zio.aws.codepipeline.model.PipelineDeclaration.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.pipeline())
        .map(value =>
          zio.aws.codepipeline.model.PipelineDeclaration.wrap(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.codepipeline.model.UpdatePipelineResponse
  ): zio.aws.codepipeline.model.UpdatePipelineResponse.ReadOnly = new Wrapper(
    impl
  )
}
